==> altex-0.1.0-py3-none-any.whl: altex/data.py <==
"""Data utilities for Altex charts."""

import numpy as np
import pandas as pd

try:
    from streamlit import cache_data  # streamlit >= 1.18.0
except ImportError:
    from streamlit import experimental_memo as cache_data  # streamlit >= 0.89


def _url_to_dataframe(url: str) -> pd.DataFrame:
    """Collects a CSV/JSON file from a URL and load it into a dataframe.

    Args:
        url: URL of the CSV/JSON file

    Returns:
        Resulting dataframe
    """
    if url.endswith(".csv"):
        return pd.read_csv(url)
    if url.endswith(".json"):
        return pd.read_json(url)
    raise Exception("URL must end with .json or .csv")


# Sample data URLs
WEATHER_DATA_URL = (
    "https://raw.githubusercontent.com/tvst/plost/master/data/seattle-weather.csv"
)
STOCKS_DATA_URL = (
    "https://raw.githubusercontent.com/vega/vega/main/docs/data/stocks.csv"
)
BARLEY_DATA_URL = (
    "https://raw.githubusercontent.com/vega/vega/main/docs/data/barley.json"
)


@cache_data
def get_weather_data() -> pd.DataFrame:
    """Get sample weather data from Seattle.

    Returns:
        DataFrame with weather data including temperature, wind, etc.
    """
    return _url_to_dataframe(WEATHER_DATA_URL)


@cache_data
def get_stocks_data() -> pd.DataFrame:
    """Get sample stock price data.

    Returns:
        DataFrame with stock prices for different symbols over time.
    """
    return _url_to_dataframe(STOCKS_DATA_URL).assign(
        date=lambda df: pd.to_datetime(df.date)
    )


@cache_data
def get_barley_data() -> pd.DataFrame:
    """Get sample barley yield data.

    Returns:
        DataFrame with barley yield data by variety and site.
    """
    return _url_to_dataframe(BARLEY_DATA_URL)


def get_random_data() -> pd.DataFrame:
    """Generate random sample data.

    Returns:
        DataFrame with random numerical data.
    """
    return pd.DataFrame(
        np.random.randn(20, 7),
        columns=list("abcdefg"),
    ).reset_index()

==> altex-0.2.0-py3-none-any.whl: altex/data.py <==
"""Data utilities for Altex charts."""

from pathlib import Path

import pandas as pd

try:
    from streamlit import cache_data  # streamlit >= 1.18.0
except ImportError:
    from streamlit import experimental_memo as cache_data  # streamlit >= 0.89

# Get the directory where this file is located
DATA_DIR = Path(__file__).parent / "data"


@cache_data
def get_weather_data() -> pd.DataFrame:
    """Get sample weather data from Seattle.

    Returns:
        DataFrame with weather data including temperature, wind, etc.
    """
    return pd.read_csv(DATA_DIR / "weather.csv")


@cache_data
def get_stocks_data() -> pd.DataFrame:
    """Get sample stock price data.

    Returns:
        DataFrame with stock prices for different symbols over time.
    """
    return pd.read_csv(DATA_DIR / "stocks.csv").assign(
        date=lambda df: pd.to_datetime(df.date)
    )


@cache_data
def get_barley_data() -> pd.DataFrame:
    """Get sample barley yield data.

    Returns:
        DataFrame with barley yield data by variety and site.
    """
    return pd.read_json(DATA_DIR / "barley.json")


def get_random_data() -> pd.DataFrame:
    """Generate random sample data.

    Returns:
        DataFrame with random numerical data.
    """
    # Use pandas instead of numpy for random data
    import random

    random.seed(42)  # For reproducible "random" data
    data = {}

    for col in "abcdefg":
        # Generate 20 random values between -2 and 2
        data[col] = [random.uniform(-2, 2) for _ in range(20)]

    return pd.DataFrame(data).reset_index()
